@@ -2,7 +2,7 @@
  * Programmer(s): Daniel R. Reynolds @ SMU
  *---------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2023, Lawrence Livermore National Security
+ * Copyright (c) 2002-2024, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -31,13 +31,13 @@
  *-----------------------------------------------------------------*/
 
 /* Header files */
-#include <stdio.h>
+#include <arkode/arkode_arkstep.h> /* prototypes for ARKStep fcts., consts */
 #include <math.h>
-#include <arkode/arkode_arkstep.h>         /* prototypes for ARKStep fcts., consts */
-#include <nvector/nvector_serial.h>        /* serial N_Vector types, fcts., macros */
-#include <sunmatrix/sunmatrix_dense.h>     /* access to dense SUNMatrix            */
-#include <sunlinsol/sunlinsol_dense.h>     /* access to dense SUNLinearSolver      */
-#include <sundials/sundials_types.h>       /* definition of type realtype          */
+#include <nvector/nvector_serial.h> /* serial N_Vector types, fcts., macros */
+#include <stdio.h>
+#include <sundials/sundials_types.h> /* definition of type sunrealtype          */
+#include <sunlinsol/sunlinsol_dense.h> /* access to dense SUNLinearSolver      */
+#include <sunmatrix/sunmatrix_dense.h> /* access to dense SUNMatrix            */
 
 #if defined(SUNDIALS_EXTENDED_PRECISION)
 #define GSYM "Lg"
@@ -50,107 +50,114 @@
 #endif
 
 /* User-supplied Functions Called by the Solver */
-static int f(realtype t, N_Vector y, N_Vector ydot, void *user_data);
-static int Jac(realtype t, N_Vector y, N_Vector fy, SUNMatrix J,
-               void *user_data, N_Vector tmp1, N_Vector tmp2, N_Vector tmp3);
+static int f(sunrealtype t, N_Vector y, N_Vector ydot, void* user_data);
+static int Jac(sunrealtype t, N_Vector y, N_Vector fy, SUNMatrix J,
+               void* user_data, N_Vector tmp1, N_Vector tmp2, N_Vector tmp3);
 
 /* Private function to check function return values */
-static int check_flag(void *flagvalue, const char *funcname, int opt);
+static int check_flag(void* flagvalue, const char* funcname, int opt);
 
 /* Private function to check computed solution */
-static int check_ans(N_Vector y, realtype t, realtype rtol, realtype atol);
+static int check_ans(N_Vector y, sunrealtype t, sunrealtype rtol,
+                     sunrealtype atol);
 
 /* Main Program */
-int main()
+int main(void)
 {
   /* general problem parameters */
-  realtype T0 = RCONST(0.0);         /* initial time */
-  realtype Tf = RCONST(10.0);        /* final time */
-  realtype dTout = RCONST(1.0);      /* time between outputs */
-  sunindextype NEQ = 1;              /* number of dependent vars. */
-  realtype reltol = RCONST(1.0e-6);  /* tolerances */
-  realtype abstol = RCONST(1.0e-10);
-  realtype lamda  = RCONST(-100.0);  /* stiffness parameter */
+  sunrealtype T0     = SUN_RCONST(0.0);    /* initial time */
+  sunrealtype Tf     = SUN_RCONST(10.0);   /* final time */
+  sunrealtype dTout  = SUN_RCONST(1.0);    /* time between outputs */
+  sunindextype NEQ   = 1;                  /* number of dependent vars. */
+  sunrealtype reltol = SUN_RCONST(1.0e-6); /* tolerances */
+  sunrealtype abstol = SUN_RCONST(1.0e-10);
+  sunrealtype lamda  = SUN_RCONST(-100.0); /* stiffness parameter */
 
   /* general problem variables */
-  int flag;                       /* reusable error-checking flag */
-  N_Vector y = NULL;              /* empty vector for storing solution */
-  SUNMatrix A = NULL;             /* empty matrix for linear solver */
-  SUNLinearSolver LS = NULL;      /* empty linear solver object */
-  void *arkode_mem = NULL;        /* empty ARKode memory structure */
-  FILE *UFID;
-  realtype t, tout;
+  int flag;                  /* reusable error-checking flag */
+  N_Vector y         = NULL; /* empty vector for storing solution */
+  SUNMatrix A        = NULL; /* empty matrix for linear solver */
+  SUNLinearSolver LS = NULL; /* empty linear solver object */
+  void* arkode_mem   = NULL; /* empty ARKode memory structure */
+  FILE* UFID;
+  sunrealtype t, tout;
   long int nst, nst_a, nfe, nfi, nsetups, nje, nfeLS, nni, ncfn, netf;
 
   /* Create the SUNDIALS context object for this simulation */
   SUNContext ctx;
-  flag = SUNContext_Create(NULL, &ctx);
-  if (check_flag(&flag, "SUNContext_Create", 1)) return 1;
+  flag = SUNContext_Create(SUN_COMM_NULL, &ctx);
+  if (check_flag(&flag, "SUNContext_Create", 1)) { return 1; }
 
   /* Initial diagnostics output */
   printf("\nAnalytical ODE test problem:\n");
-  printf("    lamda = %"GSYM"\n",    lamda);
-  printf("   reltol = %.1"ESYM"\n",  reltol);
-  printf("   abstol = %.1"ESYM"\n\n",abstol);
+  printf("    lamda = %" GSYM "\n", lamda);
+  printf("   reltol = %.1" ESYM "\n", reltol);
+  printf("   abstol = %.1" ESYM "\n\n", abstol);
 
   /* Initialize data structures */
-  y = N_VNew_Serial(NEQ, ctx);          /* Create serial vector for solution */
-  if (check_flag((void *)y, "N_VNew_Serial", 0)) return 1;
-  N_VConst(RCONST(0.0), y);        /* Specify initial condition */
+  y = N_VNew_Serial(NEQ, ctx); /* Create serial vector for solution */
+  if (check_flag((void*)y, "N_VNew_Serial", 0)) { return 1; }
+  N_VConst(SUN_RCONST(0.0), y); /* Specify initial condition */
 
   /* Call ARKStepCreate to initialize the ARK timestepper module and
      specify the right-hand side function in y'=f(t,y), the inital time
      T0, and the initial dependent variable vector y.  Note: since this
      problem is fully implicit, we set f_E to NULL and f_I to f. */
   arkode_mem = ARKStepCreate(NULL, f, T0, y, ctx);
-  if (check_flag((void *)arkode_mem, "ARKStepCreate", 0)) return 1;
+  if (check_flag((void*)arkode_mem, "ARKStepCreate", 0)) { return 1; }
 
   /* Set routines */
-  flag = ARKStepSetUserData(arkode_mem, (void *) &lamda);  /* Pass lamda to user functions */
-  if (check_flag(&flag, "ARKStepSetUserData", 1)) return 1;
-  flag = ARKStepSStolerances(arkode_mem, reltol, abstol);  /* Specify tolerances */
-  if (check_flag(&flag, "ARKStepSStolerances", 1)) return 1;
+  flag = ARKStepSetUserData(arkode_mem,
+                            (void*)&lamda); /* Pass lamda to user functions */
+  if (check_flag(&flag, "ARKStepSetUserData", 1)) { return 1; }
+  flag = ARKStepSStolerances(arkode_mem, reltol, abstol); /* Specify tolerances */
+  if (check_flag(&flag, "ARKStepSStolerances", 1)) { return 1; }
 
   /* Initialize dense matrix data structure and solver */
   A = SUNDenseMatrix(NEQ, NEQ, ctx);
-  if (check_flag((void *)A, "SUNDenseMatrix", 0)) return 1;
+  if (check_flag((void*)A, "SUNDenseMatrix", 0)) { return 1; }
   LS = SUNLinSol_Dense(y, A, ctx);
-  if (check_flag((void *)LS, "SUNLinSol_Dense", 0)) return 1;
+  if (check_flag((void*)LS, "SUNLinSol_Dense", 0)) { return 1; }
 
   /* Linear solver interface */
-  flag = ARKStepSetLinearSolver(arkode_mem, LS, A);        /* Attach matrix and linear solver */
-  if (check_flag(&flag, "ARKStepSetLinearSolver", 1)) return 1;
-  flag = ARKStepSetJacFn(arkode_mem, Jac);                 /* Set Jacobian routine */
-  if (check_flag(&flag, "ARKStepSetJacFn", 1)) return 1;
+  flag = ARKStepSetLinearSolver(arkode_mem, LS,
+                                A); /* Attach matrix and linear solver */
+  if (check_flag(&flag, "ARKStepSetLinearSolver", 1)) { return 1; }
+  flag = ARKStepSetJacFn(arkode_mem, Jac); /* Set Jacobian routine */
+  if (check_flag(&flag, "ARKStepSetJacFn", 1)) { return 1; }
 
   /* Specify linearly implicit RHS, with non-time-dependent Jacobian */
   flag = ARKStepSetLinear(arkode_mem, 0);
-  if (check_flag(&flag, "ARKStepSetLinear", 1)) return 1;
+  if (check_flag(&flag, "ARKStepSetLinear", 1)) { return 1; }
 
   /* Open output stream for results, output comment line */
-  UFID = fopen("solution.txt","w");
-  fprintf(UFID,"# t u\n");
+  UFID = fopen("solution.txt", "w");
+  fprintf(UFID, "# t u\n");
 
   /* output initial condition to disk */
-  fprintf(UFID," %.16"ESYM" %.16"ESYM"\n", T0, NV_Ith_S(y,0));
+  fprintf(UFID, " %.16" ESYM " %.16" ESYM "\n", T0, NV_Ith_S(y, 0));
 
   /* Main time-stepping loop: calls ARKStepEvolve to perform the integration, then
      prints results.  Stops when the final time has been reached */
-  t = T0;
-  tout = T0+dTout;
+  t    = T0;
+  tout = T0 + dTout;
   printf("        t           u\n");
   printf("   ---------------------\n");
-  while (Tf - t > 1.0e-15) {
-
-    flag = ARKStepEvolve(arkode_mem, tout, y, &t, ARK_NORMAL);      /* call integrator */
-    if (check_flag(&flag, "ARKStepEvolve", 1)) break;
-    printf("  %10.6"FSYM"  %10.6"FSYM"\n", t, NV_Ith_S(y,0));          /* access/print solution */
-    fprintf(UFID," %.16"ESYM" %.16"ESYM"\n", t, NV_Ith_S(y,0));
-    if (flag >= 0) {                                         /* successful solve: update time */
+  while (Tf - t > 1.0e-15)
+  {
+    flag = ARKStepEvolve(arkode_mem, tout, y, &t, ARK_NORMAL); /* call integrator */
+    if (check_flag(&flag, "ARKStepEvolve", 1)) { break; }
+    printf("  %10.6" FSYM "  %10.6" FSYM "\n", t,
+           NV_Ith_S(y, 0)); /* access/print solution */
+    fprintf(UFID, " %.16" ESYM " %.16" ESYM "\n", t, NV_Ith_S(y, 0));
+    if (flag >= 0)
+    { /* successful solve: update time */
       tout += dTout;
       tout = (tout > Tf) ? Tf : tout;
-    } else {                                                 /* unsuccessful solve: break */
-      fprintf(stderr,"Solver failure, stopping integration\n");
+    }
+    else
+    { /* unsuccessful solve: break */
+      fprintf(stderr, "Solver failure, stopping integration\n");
       break;
     }
   }
@@ -205,30 +212,31 @@ int main()
  *-------------------------------*/
 
 /* f routine to compute the ODE RHS function f(t,y). */
-static int f(realtype t, N_Vector y, N_Vector ydot, void *user_data)
+static int f(sunrealtype t, N_Vector y, N_Vector ydot, void* user_data)
 {
-  realtype *rdata = (realtype *) user_data;   /* cast user_data to realtype */
-  realtype lamda = rdata[0];                  /* set shortcut for stiffness parameter */
-  realtype u = NV_Ith_S(y,0);                 /* access current solution value */
+  sunrealtype* rdata = (sunrealtype*)user_data; /* cast user_data to sunrealtype */
+  sunrealtype lamda = rdata[0];       /* set shortcut for stiffness parameter */
+  sunrealtype u     = NV_Ith_S(y, 0); /* access current solution value */
 
   /* fill in the RHS function: "NV_Ith_S" accesses the 0th entry of ydot */
-  NV_Ith_S(ydot,0) = lamda*u + RCONST(1.0)/(RCONST(1.0)+t*t) - lamda*atan(t);
+  NV_Ith_S(ydot, 0) = lamda * u + SUN_RCONST(1.0) / (SUN_RCONST(1.0) + t * t) -
+                      lamda * atan(t);
 
-  return 0;                                   /* return with success */
+  return 0; /* return with success */
 }
 
 /* Jacobian routine to compute J(t,y) = df/dy. */
-static int Jac(realtype t, N_Vector y, N_Vector fy, SUNMatrix J,
-               void *user_data, N_Vector tmp1, N_Vector tmp2, N_Vector tmp3)
+static int Jac(sunrealtype t, N_Vector y, N_Vector fy, SUNMatrix J,
+               void* user_data, N_Vector tmp1, N_Vector tmp2, N_Vector tmp3)
 {
-  realtype *rdata = (realtype *) user_data;   /* cast user_data to realtype */
-  realtype lamda = rdata[0];                  /* set shortcut for stiffness parameter */
-  realtype *Jdata = SUNDenseMatrix_Data(J);
+  sunrealtype* rdata = (sunrealtype*)user_data; /* cast user_data to sunrealtype */
+  sunrealtype lamda  = rdata[0]; /* set shortcut for stiffness parameter */
+  sunrealtype* Jdata = SUNDenseMatrix_Data(J);
 
   /* Fill in Jacobian of f: set the first entry of the data array to set the (0,0) entry */
   Jdata[0] = lamda;
 
-  return 0;                                   /* return with success */
+  return 0; /* return with success */
 }
 
 /*-------------------------------
@@ -243,52 +251,61 @@ static int Jac(realtype t, N_Vector y, N_Vector fy, SUNMatrix J,
     opt == 2 means function allocates memory so check if returned
              NULL pointer
 */
-static int check_flag(void *flagvalue, const char *funcname, int opt)
+static int check_flag(void* flagvalue, const char* funcname, int opt)
 {
-  int *errflag;
+  int* errflag;
 
   /* Check if SUNDIALS function returned NULL pointer - no memory allocated */
-  if (opt == 0 && flagvalue == NULL) {
+  if (opt == 0 && flagvalue == NULL)
+  {
     fprintf(stderr, "\nSUNDIALS_ERROR: %s() failed - returned NULL pointer\n\n",
             funcname);
-    return 1; }
+    return 1;
+  }
 
   /* Check if flag < 0 */
-  else if (opt == 1) {
-    errflag = (int *) flagvalue;
-    if (*errflag < 0) {
+  else if (opt == 1)
+  {
+    errflag = (int*)flagvalue;
+    if (*errflag < 0)
+    {
       fprintf(stderr, "\nSUNDIALS_ERROR: %s() failed with flag = %d\n\n",
               funcname, *errflag);
-      return 1; }}
+      return 1;
+    }
+  }
 
   /* Check if function returned NULL pointer - no memory allocated */
-  else if (opt == 2 && flagvalue == NULL) {
+  else if (opt == 2 && flagvalue == NULL)
+  {
     fprintf(stderr, "\nMEMORY_ERROR: %s() failed - returned NULL pointer\n\n",
             funcname);
-    return 1; }
+    return 1;
+  }
 
   return 0;
 }
 
 /* check the computed solution */
-static int check_ans(N_Vector y, realtype t, realtype rtol, realtype atol)
+static int check_ans(N_Vector y, sunrealtype t, sunrealtype rtol, sunrealtype atol)
 {
-  int      passfail=0;     /* answer pass (0) or fail (1) flag     */
-  realtype ans, err, ewt;  /* answer data, error, and error weight */
+  int passfail = 0;          /* answer pass (0) or fail (1) flag     */
+  sunrealtype ans, err, ewt; /* answer data, error, and error weight */
 
   /* compute solution error */
   ans = atan(t);
-  ewt = RCONST(1.0) / (rtol * fabs(ans) + atol);
-  err = ewt * fabs(NV_Ith_S(y,0) - ans);
+  ewt = SUN_RCONST(1.0) / (rtol * fabs(ans) + atol);
+  err = ewt * fabs(NV_Ith_S(y, 0) - ans);
 
   /* is the solution within the tolerances? */
-  passfail = (err < RCONST(1.0)) ? 0 : 1;
+  passfail = (err < SUN_RCONST(1.0)) ? 0 : 1;
 
-  if (passfail) {
-    fprintf(stdout, "\nSUNDIALS_WARNING: check_ans error=%"GSYM"\n\n", err);
+  if (passfail)
+  {
+    fprintf(stdout, "\nSUNDIALS_WARNING: check_ans error=%" GSYM "\n\n", err);
   }
 
-  return(passfail);
+  return (passfail);
 }
 
 /*---- end of file ----*/
